==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/FinancialIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialSeriesDescriptionMetadata } from "./FinancialSeriesDescriptionMetadata";
/**
 * @hidden
 */
var FinancialIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FinancialIndicatorDescriptionMetadata, _super);
    function FinancialIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FinancialIndicatorDescriptionMetadata.b = function (a) {
        if (FinancialIndicatorDescriptionMetadata.a == null) {
            FinancialIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FinancialIndicatorDescriptionMetadata.c(FinancialIndicatorDescriptionMetadata.a);
        }
        if (a.g(FinancialIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(FinancialIndicatorDescriptionMetadata.a);
    };
    FinancialIndicatorDescriptionMetadata.c = function (a) {
        FinancialSeriesDescriptionMetadata.c(a);
        a.item("DisplayType", "ExportedType:string:IndicatorDisplayType");
        a.item("DisplayType@names", "Line;Area;Column");
        a.item("IgnoreFirst", "Number:int");
        a.item("TrendLineType", "ExportedType:string:TrendLineType");
        a.item("TrendLineType@names", "None;LinearFit;QuadraticFit;CubicFit;QuarticFit;QuinticFit;LogarithmicFit;ExponentialFit;PowerLawFit;SimpleAverage;ExponentialAverage;ModifiedAverage;CumulativeAverage;WeightedAverage");
        a.item("TrendLineBrush", "Brush");
        a.item("ActualTrendLineBrush", "Brush");
        a.item("TrendLineThickness", "Number:double");
        a.item("TrendLinePeriod", "Number:int");
    };
    FinancialIndicatorDescriptionMetadata.d = function (a) {
        FinancialIndicatorDescriptionMetadata.b(a);
        a.t("FinancialIndicator", FinancialIndicatorDescriptionMetadata.a);
    };
    FinancialIndicatorDescriptionMetadata.$t = markType(FinancialIndicatorDescriptionMetadata, 'FinancialIndicatorDescriptionMetadata');
    FinancialIndicatorDescriptionMetadata.a = null;
    return FinancialIndicatorDescriptionMetadata;
}(Base));
export { FinancialIndicatorDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/FinancialIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialSeriesDescriptionMetadata } from "./FinancialSeriesDescriptionMetadata";
/**
 * @hidden
 */
var FinancialIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FinancialIndicatorDescriptionMetadata, _super);
    function FinancialIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FinancialIndicatorDescriptionMetadata.b = function (a) {
        if (FinancialIndicatorDescriptionMetadata.a == null) {
            FinancialIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FinancialIndicatorDescriptionMetadata.c(FinancialIndicatorDescriptionMetadata.a);
        }
        if (a.j(FinancialIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(FinancialIndicatorDescriptionMetadata.a);
    };
    FinancialIndicatorDescriptionMetadata.c = function (a) {
        FinancialSeriesDescriptionMetadata.c(a);
        a.item("DisplayType", "ExportedType:string:IndicatorDisplayType");
        a.item("DisplayType@names", "Line;Area;Column");
        a.item("IgnoreFirst", "Number:int");
        a.item("TrendLineType", "ExportedType:string:TrendLineType");
        a.item("TrendLineType@names", "None;LinearFit;QuadraticFit;CubicFit;QuarticFit;QuinticFit;LogarithmicFit;ExponentialFit;PowerLawFit;SimpleAverage;ExponentialAverage;ModifiedAverage;CumulativeAverage;WeightedAverage");
        a.item("TrendLineBrush", "Brush");
        a.item("ActualTrendLineBrush", "Brush");
        a.item("TrendLineThickness", "Number:double");
        a.item("TrendLinePeriod", "Number:int");
    };
    FinancialIndicatorDescriptionMetadata.d = function (a) {
        FinancialIndicatorDescriptionMetadata.b(a);
        a.z("FinancialIndicator", FinancialIndicatorDescriptionMetadata.a);
    };
    FinancialIndicatorDescriptionMetadata.$t = markType(FinancialIndicatorDescriptionMetadata, 'FinancialIndicatorDescriptionMetadata');
    FinancialIndicatorDescriptionMetadata.a = null;
    return FinancialIndicatorDescriptionMetadata;
}(Base));
export { FinancialIndicatorDescriptionMetadata };
